@@ -86,7 +86,7 @@ class DebugToolbar:
                     "The debug toolbar requires the staticfiles contrib app. "
                     "Add 'django.contrib.staticfiles' to INSTALLED_APPS and "
                     "define STATIC_URL in your settings."
-                )
+                ) from None
             else:
                 raise
 
@@ -95,9 +95,13 @@ class DebugToolbar:
 
         If False, the panels will be loaded via Ajax.
         """
-        render_panels = self.config["RENDER_PANELS"]
-        if render_panels is None:
-            render_panels = self.request.META["wsgi.multiprocess"]
+        if (render_panels := self.config["RENDER_PANELS"]) is None:
+            # If wsgi.multiprocess isn't in the headers, then it's likely
+            # being served by ASGI. This type of set up is most likely
+            # incompatible with the toolbar until
+            # https://github.com/jazzband/django-debug-toolbar/issues/1430
+            # is resolved.
+            render_panels = self.request.META.get("wsgi.multiprocess", True)
         return render_panels
 
     # Handle storing toolbars in memory and fetching them later on
@@ -181,4 +185,4 @@ def observe_request(request):
     """
     Determine whether to update the toolbar from a client side request.
     """
-    return not DebugToolbar.is_toolbar_request(request)
+    return True
